@@ -40,12 +40,12 @@ private:
 	int m_id;
 	int m_serverId;
 	std::unique_ptr<Connection> m_connection;
-	int m_latency;
-	int m_speed;
 	const char* m_dataDir;
 	const char* m_cacheDir;
 	const char* m_secureCert;
 	const char* m_secureKey;
+	int m_latency;
+	int m_speed;
 	const char* m_messageid;
 	CString m_filename;
 	int m_part;
@@ -103,7 +103,7 @@ void NntpServer::Run()
 				break;
 			}
 			m_connection.reset();
-			usleep(500 * 1000);
+			Util::Sleep(500);
 			continue;
 		}
 		
@@ -172,7 +172,7 @@ void NntpProcessor::Run()
 		}
 		else if (!strncasecmp(line, "GROUP ", 6))
 		{
-			m_connection->WriteLine(CString::FormatStr("211 0 0 0 %s\r\n", line + 7));
+			m_connection->WriteLine(CString::FormatStr("211 0 0 0 %s\r\n", line + 6));
 		}
 		else if (!strncasecmp(line, "AUTHINFO ", 9))
 		{
@@ -216,7 +216,7 @@ void NntpProcessor::ServArticle()
 
 	if (m_latency)
 	{
-		usleep(1000 * m_latency);
+		Util::Sleep(m_latency);
 	}
 
 	bool ok = false;
@@ -268,16 +268,16 @@ bool NntpProcessor::ServerInList(const char* servList)
 
 void NntpProcessor::SendSegment()
 {
-	detail("[%i] Sending segment %s (%i=%lli:%i)", m_id, *m_filename, m_part, (long long)m_offset, m_size);
+	detail("[%i] Sending segment %s (%i=%" PRIi64 ":%i)", m_id, *m_filename, m_part, m_offset, m_size);
 
 	if (m_speed > 0)
 	{
-		m_start = Util::GetCurrentTicks();
+		m_start = Util::CurrentTicks();
 	}
 
 	BString<1024> fullFilename("%s/%s", m_dataDir, *m_filename);
 	BString<1024> cacheFileDir("%s/%s", m_cacheDir, *m_filename);
-	BString<1024> cacheFileName("%i=%lli-%i", m_part, (long long)m_offset, m_size);
+	BString<1024> cacheFileName("%i=%" PRIi64 "-%i", m_part, m_offset, m_size);
 	BString<1024> cacheFullFilename("%s/%s", *cacheFileDir, *cacheFileName);
 	BString<1024> cacheKey("%s/%s", *m_filename, *cacheFileName);
 
@@ -383,7 +383,7 @@ void NntpProcessor::SendData(const char* buffer, int size)
 		return;
 	}
 
-	int64 expectedTime = (int64)1000 * size / (m_speed * 1024) - (Util::GetCurrentTicks() - m_start) / 1000;
+	int64 expectedTime = (int64)1000 * size / (m_speed * 1024) - (Util::CurrentTicks() - m_start) / 1000;
 
 	int chunkNum = 21;
 	int chunkSize = size;
@@ -407,10 +407,10 @@ void NntpProcessor::SendData(const char* buffer, int size)
 		}
 		
 		m_connection->Send(buffer + sent, len);
-		int64 now = Util::GetCurrentTicks();
+		int64 now = Util::CurrentTicks();
 		if (now + pause * 1000 < m_start + expectedTime * 1000)
 		{
-			usleep(pause * 1000);
+			Util::Sleep(pause);
 		}
 		sent += len;
 	}
